@@ -1,9 +1,17 @@
 var files_dup =
 [
+    [ "access-flatpak.c", "access-flatpak_8c.html", "access-flatpak_8c" ],
+    [ "access-portal.c", "access-portal_8c.html", "access-portal_8c" ],
     [ "alloc.h", "alloc_8h.html", "alloc_8h" ],
+    [ "alsa-endpoint.c", "alsa-endpoint_8c.html", "alsa-endpoint_8c" ],
+    [ "alsa-midi.c", "alsa-midi_8c.html", "alsa-midi_8c" ],
+    [ "alsa-monitor.c", "alsa-monitor_8c.html", "alsa-monitor_8c" ],
     [ "ansi.h", "ansi_8h.html", "ansi_8h" ],
     [ "array.h", "array_8h.html", "array_8h" ],
     [ "audio.h", "audio_8h.html", "audio_8h" ],
+    [ "bluez-autoswitch.c", "bluez-autoswitch_8c.html", "bluez-autoswitch_8c" ],
+    [ "bluez-endpoint.c", "bluez-endpoint_8c.html", "bluez-endpoint_8c" ],
+    [ "bluez-monitor.c", "bluez-monitor_8c.html", "bluez-monitor_8c" ],
     [ "buffer/buffer.h", "buffer_2buffer_8h.html", "buffer_2buffer_8h" ],
     [ "debug/buffer.h", "debug_2buffer_8h.html", "debug_2buffer_8h" ],
     [ "buffers.c", "buffers_8c.html", "buffers_8c" ],
@@ -28,6 +36,9 @@ var files_dup =
     [ "data-loop.c", "data-loop_8c.html", "data-loop_8c" ],
     [ "data-loop.h", "data-loop_8h.html", "data-loop_8h" ],
     [ "dbus.h", "dbus_8h.html", "dbus_8h" ],
+    [ "default-nodes.c", "default-nodes_8c.html", "default-nodes_8c" ],
+    [ "default-profile.c", "default-profile_8c.html", "default-profile_8c" ],
+    [ "default-routes.c", "default-routes_8c.html", "default-routes_8c" ],
     [ "defs.h", "defs_8h.html", "defs_8h" ],
     [ "pipewire/src/pipewire/device.h", "pipewire_2src_2pipewire_2device_8h.html", "pipewire_2src_2pipewire_2device_8h" ],
     [ "build/doc/spa/monitor/device.h", "build_2doc_2spa_2monitor_2device_8h.html", "build_2doc_2spa_2monitor_2device_8h" ],
@@ -54,6 +65,7 @@ var files_dup =
     [ "hook.h", "hook_8h.html", "hook_8h" ],
     [ "pipewire/src/pipewire/i18n.h", "pipewire_2src_2pipewire_2i18n_8h.html", "pipewire_2src_2pipewire_2i18n_8h" ],
     [ "build/doc/spa/support/i18n.h", "build_2doc_2spa_2support_2i18n_8h.html", "build_2doc_2spa_2support_2i18n_8h" ],
+    [ "iec958.h", "iec958_8h.html", "iec958_8h" ],
     [ "impl-client.c", "impl-client_8c.html", "impl-client_8c" ],
     [ "impl-client.h", "impl-client_8h.html", "impl-client_8h" ],
     [ "impl-core.c", "impl-core_8c.html", "impl-core_8c" ],
@@ -82,22 +94,27 @@ var files_dup =
     [ "build/doc/spa/utils/keys.h", "build_2doc_2spa_2utils_2keys_8h.html", "build_2doc_2spa_2utils_2keys_8h" ],
     [ "latency-utils.h", "latency-utils_8h.html", "latency-utils_8h" ],
     [ "layout.h", "layout_8h.html", "layout_8h" ],
+    [ "libcamera-monitor.c", "libcamera-monitor_8c.html", "libcamera-monitor_8c" ],
     [ "link.h", "link_8h.html", "link_8h" ],
     [ "list.h", "list_8h.html", "list_8h" ],
     [ "log-impl.h", "log-impl_8h.html", "log-impl_8h" ],
     [ "log.c", "log_8c.html", "log_8c" ],
     [ "pipewire/src/pipewire/log.h", "pipewire_2src_2pipewire_2log_8h.html", "pipewire_2src_2pipewire_2log_8h" ],
     [ "build/doc/spa/support/log.h", "build_2doc_2spa_2support_2log_8h.html", "build_2doc_2spa_2support_2log_8h" ],
+    [ "logind.c", "logind_8c.html", "logind_8c" ],
     [ "loop.c", "loop_8c.html", "loop_8c" ],
     [ "pipewire/src/pipewire/loop.h", "pipewire_2src_2pipewire_2loop_8h.html", "pipewire_2src_2pipewire_2loop_8h" ],
     [ "build/doc/spa/support/loop.h", "build_2doc_2spa_2support_2loop_8h.html", "build_2doc_2spa_2support_2loop_8h" ],
     [ "main-loop.c", "main-loop_8c.html", "main-loop_8c" ],
     [ "main-loop.h", "main-loop_8h.html", "main-loop_8h" ],
     [ "map.h", "map_8h.html", "map_8h" ],
+    [ "match-rules.c", "match-rules_8c.html", "match-rules_8c" ],
+    [ "media-session.c", "media-session_8c.html", "media-session_8c" ],
     [ "mem.c", "mem_8c.html", "mem_8c" ],
     [ "pipewire/src/pipewire/mem.h", "pipewire_2src_2pipewire_2mem_8h.html", "pipewire_2src_2pipewire_2mem_8h" ],
     [ "build/doc/spa/debug/mem.h", "build_2doc_2spa_2debug_2mem_8h.html", "build_2doc_2spa_2debug_2mem_8h" ],
     [ "meta.h", "meta_8h.html", "meta_8h" ],
+    [ "metadata.c", "metadata_8c.html", "metadata_8c" ],
     [ "module-access.c", "module-access_8c.html", "module-access_8c" ],
     [ "module-adapter.c", "module-adapter_8c.html", "module-adapter_8c" ],
     [ "module-client-device.c", "module-client-device_8c.html", "module-client-device_8c" ],
@@ -135,6 +152,8 @@ var files_dup =
     [ "plugin.h", "plugin_8h.html", "plugin_8h" ],
     [ "debug/pod.h", "debug_2pod_8h.html", "debug_2pod_8h" ],
     [ "pod/pod.h", "pod_2pod_8h.html", "pod_2pod_8h" ],
+    [ "policy-ep.c", "policy-ep_8c.html", "policy-ep_8c" ],
+    [ "policy-node.c", "policy-node_8c.html", "policy-node_8c" ],
     [ "port.h", "port_8h.html", "port_8h" ],
     [ "profiler.h", "profiler_8h.html", "profiler_8h" ],
     [ "properties.c", "properties_8c.html", "properties_8c" ],
@@ -149,12 +168,17 @@ var files_dup =
     [ "video/raw.h", "video_2raw_8h.html", "video_2raw_8h" ],
     [ "resource.c", "resource_8c.html", "resource_8c" ],
     [ "resource.h", "resource_8h.html", "resource_8h" ],
+    [ "restore-stream.c", "restore-stream_8c.html", "restore-stream_8c" ],
     [ "result.h", "result_8h.html", "result_8h" ],
     [ "ringbuffer.h", "ringbuffer_8h.html", "ringbuffer_8h" ],
+    [ "session-manager.c", "session-manager_8c.html", "session-manager_8c" ],
     [ "settings.c", "settings_8c.html", "settings_8c" ],
+    [ "stream-endpoint.c", "stream-endpoint_8c.html", "stream-endpoint_8c" ],
     [ "stream.c", "stream_8c.html", "stream_8c" ],
     [ "stream.h", "stream_8h.html", "stream_8h" ],
+    [ "streams-follow-default.c", "streams-follow-default_8c.html", "streams-follow-default_8c" ],
     [ "string.h", "string_8h.html", "string_8h" ],
+    [ "suspend-node.c", "suspend-node_8c.html", "suspend-node_8c" ],
     [ "system.h", "system_8h.html", "system_8h" ],
     [ "thread-loop.c", "thread-loop_8c.html", "thread-loop_8c" ],
     [ "thread-loop.h", "thread-loop_8h.html", "thread-loop_8h" ],
@@ -177,6 +201,8 @@ var files_dup =
     [ "pipewire/src/pipewire/utils.h", "pipewire_2src_2pipewire_2utils_8h.html", "pipewire_2src_2pipewire_2utils_8h" ],
     [ "build/doc/spa/monitor/utils.h", "build_2doc_2spa_2monitor_2utils_8h.html", "build_2doc_2spa_2monitor_2utils_8h" ],
     [ "build/doc/spa/node/utils.h", "build_2doc_2spa_2node_2utils_8h.html", "build_2doc_2spa_2node_2utils_8h" ],
+    [ "v4l2-endpoint.c", "v4l2-endpoint_8c.html", "v4l2-endpoint_8c" ],
+    [ "v4l2-monitor.c", "v4l2-monitor_8c.html", "v4l2-monitor_8c" ],
     [ "vararg.h", "vararg_8h.html", "vararg_8h" ],
     [ "work-queue.c", "work-queue_8c.html", "work-queue_8c" ],
     [ "work-queue.h", "work-queue_8h.html", "work-queue_8h" ]
