@@ -42,14 +42,20 @@ var NAVTREEINDEX0 =
 "array_8h_source.html":[9,0,7],
 "audio_2format-utils_8h.html":[9,0,52],
 "audio_2format-utils_8h_source.html":[9,0,52],
-"audio_2raw_8h.html":[9,0,163],
-"audio_2raw_8h_source.html":[9,0,163],
+"audio_2raw_8h.html":[9,0,164],
+"audio_2raw_8h_source.html":[9,0,164],
 "audio_8h.html":[9,0,8],
 "audio_8h_source.html":[9,0,8],
 "bluez-autoswitch_8c.html":[9,0,9],
-"bluez-autoswitch_8c.html#a3ca694e3fdfbe66ca8625f34c02d1191":[9,0,9,7],
+"bluez-autoswitch_8c.html#a0fa8f86b49f5273b0987658921f3dae5":[9,0,9,7],
+"bluez-autoswitch_8c.html#a3ca694e3fdfbe66ca8625f34c02d1191":[9,0,9,13],
 "bluez-autoswitch_8c.html#a47f2e62c0dbebc787052c165afcada0e":[9,0,9,4],
+"bluez-autoswitch_8c.html#a7a95f5a8add9d7eda9c69b869aa99b64":[9,0,9,11],
+"bluez-autoswitch_8c.html#a87cc4fb2427aff65828e5f5c74ac2411":[9,0,9,12],
 "bluez-autoswitch_8c.html#a894b84c8f5ff621bf7f7ed71c990b651":[9,0,9,6],
+"bluez-autoswitch_8c.html#a8e3661c27c0dfb3d7d92493d3695d28a":[9,0,9,9],
+"bluez-autoswitch_8c.html#aab67c3a9eae016857c1231caf50a9ac1":[9,0,9,10],
+"bluez-autoswitch_8c.html#add748ac79c3cda256af3f8fb2bd48388":[9,0,9,8],
 "bluez-autoswitch_8c.html#ae61b871e183d99fb52cae34575faac9d":[9,0,9,5],
 "bluez-autoswitch_8c.html#ae6a51a1ae9635ff30bd113b6b698be11":[9,0,9,3],
 "bluez-endpoint_8c.html":[9,0,10],
@@ -70,8 +76,8 @@ var NAVTREEINDEX0 =
 "buffer_2buffer_8h.html#ab136c278867d4077904c175b638172e2":[9,0,12,2],
 "buffer_2buffer_8h.html#ac7b55666bda884c3efac917e4648338b":[9,0,12,1],
 "buffer_2buffer_8h_source.html":[9,0,12],
-"buffer_2type-info_8h.html":[9,0,184],
-"buffer_2type-info_8h_source.html":[9,0,184],
+"buffer_2type-info_8h.html":[9,0,185],
+"buffer_2type-info_8h_source.html":[9,0,185],
 "buffers_8c.html":[9,0,14],
 "buffers_8c.html#a096d7e73ff412f6c49fce1a8a6d99733":[9,0,14,5],
 "buffers_8c.html#a47f2e62c0dbebc787052c165afcada0e":[9,0,14,3],
@@ -88,10 +94,10 @@ var NAVTREEINDEX0 =
 "buffers_8h_source.html":[9,0,15],
 "build_2doc_2spa_2control_2control_8h.html":[9,0,29],
 "build_2doc_2spa_2control_2control_8h_source.html":[9,0,29],
-"build_2doc_2spa_2debug_2mem_8h.html":[9,0,111],
-"build_2doc_2spa_2debug_2mem_8h_source.html":[9,0,111],
-"build_2doc_2spa_2debug_2node_8h.html":[9,0,141],
-"build_2doc_2spa_2debug_2node_8h_source.html":[9,0,141],
+"build_2doc_2spa_2debug_2mem_8h.html":[9,0,112],
+"build_2doc_2spa_2debug_2mem_8h_source.html":[9,0,112],
+"build_2doc_2spa_2debug_2node_8h.html":[9,0,142],
+"build_2doc_2spa_2debug_2node_8h_source.html":[9,0,142],
 "build_2doc_2spa_2monitor_2device_8h.html":[9,0,41],
 "build_2doc_2spa_2monitor_2device_8h.html#a0ecfe713ec074a6d73cb8abd986f9ffd":[9,0,41,53],
 "build_2doc_2spa_2monitor_2device_8h.html#a4cde26af07d8cce0804ddb9de69070a5":[9,0,41,3],
@@ -103,69 +109,69 @@ var NAVTREEINDEX0 =
 "build_2doc_2spa_2monitor_2device_8h.html#aee6259c06260e89b9c7e6186b9975998":[9,0,41,51],
 "build_2doc_2spa_2monitor_2device_8h.html#af14cd663ab18bce958a27cbfa145a79a":[9,0,41,2],
 "build_2doc_2spa_2monitor_2device_8h_source.html":[9,0,41],
-"build_2doc_2spa_2monitor_2utils_8h.html":[9,0,198],
-"build_2doc_2spa_2monitor_2utils_8h.html#a1c95c5a55d127c4d928fd30dc0979a7c":[9,0,198,2],
-"build_2doc_2spa_2monitor_2utils_8h.html#a2bd95e2462bc66fff656e3ce1154a039":[9,0,198,5],
-"build_2doc_2spa_2monitor_2utils_8h.html#a32335a520788d0b69637e4dcff57a4b7":[9,0,198,6],
-"build_2doc_2spa_2monitor_2utils_8h.html#a6573dc405f256f96d9ec6b6518c5c6d8":[9,0,198,3],
-"build_2doc_2spa_2monitor_2utils_8h.html#a756d90f78ac51e42bcfd0405b40e2fb9":[9,0,198,4],
-"build_2doc_2spa_2monitor_2utils_8h.html#a9255b8edf12dacf67265325d45dae1a8":[9,0,198,7],
-"build_2doc_2spa_2monitor_2utils_8h.html#abcb2230b6ab2020ceef73fad9e1fd7dc":[9,0,198,1],
-"build_2doc_2spa_2monitor_2utils_8h_source.html":[9,0,198],
-"build_2doc_2spa_2node_2keys_8h.html":[9,0,89],
-"build_2doc_2spa_2node_2keys_8h_source.html":[9,0,89],
-"build_2doc_2spa_2node_2node_8h.html":[9,0,142],
-"build_2doc_2spa_2node_2node_8h.html#a07ad0379142c8c8e52b3cebf98a573ba":[9,0,142,56],
-"build_2doc_2spa_2node_2node_8h.html#a133da45e18e57716cf10424acd051d34":[9,0,142,58],
-"build_2doc_2spa_2node_2node_8h.html#a1494d415d780514b25eab3cbcbdd588d":[9,0,142,62],
-"build_2doc_2spa_2node_2node_8h.html#a279d6e7c36c46cc531079d442f4c87bc":[9,0,142,66],
-"build_2doc_2spa_2node_2node_8h.html#a2f6a9687ad84fb6f7f7ffb4547c49b3e":[9,0,142,60],
-"build_2doc_2spa_2node_2node_8h.html#a32e97ff007afd7fa67a218705a93a4fa":[9,0,142,17],
-"build_2doc_2spa_2node_2node_8h.html#a33050ccc32ba7651ece70172b94bb026":[9,0,142,67],
-"build_2doc_2spa_2node_2node_8h.html#a3e71660c556d55e8f71f14114156579d":[9,0,142,59],
-"build_2doc_2spa_2node_2node_8h.html#a42aef9e39e095e1a8ff2a18a650eebff":[9,0,142,20],
-"build_2doc_2spa_2node_2node_8h.html#a5c50b8909b0b6bb8822b8072c97012c5":[9,0,142,61],
-"build_2doc_2spa_2node_2node_8h.html#a5da30323ece5658c6b1cbcd745a1c85e":[9,0,142,74],
-"build_2doc_2spa_2node_2node_8h.html#a6dc4d1bbfffa9f49d18168d5a8302459":[9,0,142,7],
-"build_2doc_2spa_2node_2node_8h.html#a6e48491bf4103fa2bc7e120e6b4ae9ef":[9,0,142,16],
-"build_2doc_2spa_2node_2node_8h.html#a7508decf7c6d0b240bf2521a0a2652a3":[9,0,142,68],
-"build_2doc_2spa_2node_2node_8h.html#a9dab3147e13bdac986d1755ae11f4de0":[9,0,142,65],
-"build_2doc_2spa_2node_2node_8h.html#aafd293e377199e19b1a9fd1b9fd96887":[9,0,142,19],
-"build_2doc_2spa_2node_2node_8h.html#ac91f473b71a0970ff818a390a734709f":[9,0,142,21],
-"build_2doc_2spa_2node_2node_8h.html#acc3a19497d1bd883a046d8c431b08115":[9,0,142,57],
-"build_2doc_2spa_2node_2node_8h.html#acd1a9fa77a294261e70d48ec80ea2270":[9,0,142,63],
-"build_2doc_2spa_2node_2node_8h.html#ad77bdd23db7c222a58280dcda2ed63ff":[9,0,142,9],
-"build_2doc_2spa_2node_2node_8h.html#ade24550dee986c4a1279bfbaadce1636":[9,0,142,75],
-"build_2doc_2spa_2node_2node_8h.html#aee7d45b6819789bde3de86d9be592a3a":[9,0,142,76],
-"build_2doc_2spa_2node_2node_8h.html#aeee49d051bb080669113c6deeffa5d90":[9,0,142,64],
-"build_2doc_2spa_2node_2node_8h.html#af0edf0bcb3ae5739c7a528dc99fab618":[9,0,142,22],
-"build_2doc_2spa_2node_2node_8h.html#afda72bd4c75a0c9111ad4106a15d2b3e":[9,0,142,18],
-"build_2doc_2spa_2node_2node_8h.html#affb0b7df0a4786ad26e482f1372ba6a0":[9,0,142,8],
-"build_2doc_2spa_2node_2node_8h_source.html":[9,0,142],
-"build_2doc_2spa_2node_2utils_8h.html":[9,0,199],
-"build_2doc_2spa_2node_2utils_8h_source.html":[9,0,199],
+"build_2doc_2spa_2monitor_2utils_8h.html":[9,0,199],
+"build_2doc_2spa_2monitor_2utils_8h.html#a1c95c5a55d127c4d928fd30dc0979a7c":[9,0,199,2],
+"build_2doc_2spa_2monitor_2utils_8h.html#a2bd95e2462bc66fff656e3ce1154a039":[9,0,199,5],
+"build_2doc_2spa_2monitor_2utils_8h.html#a32335a520788d0b69637e4dcff57a4b7":[9,0,199,6],
+"build_2doc_2spa_2monitor_2utils_8h.html#a6573dc405f256f96d9ec6b6518c5c6d8":[9,0,199,3],
+"build_2doc_2spa_2monitor_2utils_8h.html#a756d90f78ac51e42bcfd0405b40e2fb9":[9,0,199,4],
+"build_2doc_2spa_2monitor_2utils_8h.html#a9255b8edf12dacf67265325d45dae1a8":[9,0,199,7],
+"build_2doc_2spa_2monitor_2utils_8h.html#abcb2230b6ab2020ceef73fad9e1fd7dc":[9,0,199,1],
+"build_2doc_2spa_2monitor_2utils_8h_source.html":[9,0,199],
+"build_2doc_2spa_2node_2keys_8h.html":[9,0,90],
+"build_2doc_2spa_2node_2keys_8h_source.html":[9,0,90],
+"build_2doc_2spa_2node_2node_8h.html":[9,0,143],
+"build_2doc_2spa_2node_2node_8h.html#a07ad0379142c8c8e52b3cebf98a573ba":[9,0,143,56],
+"build_2doc_2spa_2node_2node_8h.html#a133da45e18e57716cf10424acd051d34":[9,0,143,58],
+"build_2doc_2spa_2node_2node_8h.html#a1494d415d780514b25eab3cbcbdd588d":[9,0,143,62],
+"build_2doc_2spa_2node_2node_8h.html#a279d6e7c36c46cc531079d442f4c87bc":[9,0,143,66],
+"build_2doc_2spa_2node_2node_8h.html#a2f6a9687ad84fb6f7f7ffb4547c49b3e":[9,0,143,60],
+"build_2doc_2spa_2node_2node_8h.html#a32e97ff007afd7fa67a218705a93a4fa":[9,0,143,17],
+"build_2doc_2spa_2node_2node_8h.html#a33050ccc32ba7651ece70172b94bb026":[9,0,143,67],
+"build_2doc_2spa_2node_2node_8h.html#a3e71660c556d55e8f71f14114156579d":[9,0,143,59],
+"build_2doc_2spa_2node_2node_8h.html#a42aef9e39e095e1a8ff2a18a650eebff":[9,0,143,20],
+"build_2doc_2spa_2node_2node_8h.html#a5c50b8909b0b6bb8822b8072c97012c5":[9,0,143,61],
+"build_2doc_2spa_2node_2node_8h.html#a5da30323ece5658c6b1cbcd745a1c85e":[9,0,143,74],
+"build_2doc_2spa_2node_2node_8h.html#a6dc4d1bbfffa9f49d18168d5a8302459":[9,0,143,7],
+"build_2doc_2spa_2node_2node_8h.html#a6e48491bf4103fa2bc7e120e6b4ae9ef":[9,0,143,16],
+"build_2doc_2spa_2node_2node_8h.html#a7508decf7c6d0b240bf2521a0a2652a3":[9,0,143,68],
+"build_2doc_2spa_2node_2node_8h.html#a9dab3147e13bdac986d1755ae11f4de0":[9,0,143,65],
+"build_2doc_2spa_2node_2node_8h.html#aafd293e377199e19b1a9fd1b9fd96887":[9,0,143,19],
+"build_2doc_2spa_2node_2node_8h.html#ac91f473b71a0970ff818a390a734709f":[9,0,143,21],
+"build_2doc_2spa_2node_2node_8h.html#acc3a19497d1bd883a046d8c431b08115":[9,0,143,57],
+"build_2doc_2spa_2node_2node_8h.html#acd1a9fa77a294261e70d48ec80ea2270":[9,0,143,63],
+"build_2doc_2spa_2node_2node_8h.html#ad77bdd23db7c222a58280dcda2ed63ff":[9,0,143,9],
+"build_2doc_2spa_2node_2node_8h.html#ade24550dee986c4a1279bfbaadce1636":[9,0,143,75],
+"build_2doc_2spa_2node_2node_8h.html#aee7d45b6819789bde3de86d9be592a3a":[9,0,143,76],
+"build_2doc_2spa_2node_2node_8h.html#aeee49d051bb080669113c6deeffa5d90":[9,0,143,64],
+"build_2doc_2spa_2node_2node_8h.html#af0edf0bcb3ae5739c7a528dc99fab618":[9,0,143,22],
+"build_2doc_2spa_2node_2node_8h.html#afda72bd4c75a0c9111ad4106a15d2b3e":[9,0,143,18],
+"build_2doc_2spa_2node_2node_8h.html#affb0b7df0a4786ad26e482f1372ba6a0":[9,0,143,8],
+"build_2doc_2spa_2node_2node_8h_source.html":[9,0,143],
+"build_2doc_2spa_2node_2utils_8h.html":[9,0,200],
+"build_2doc_2spa_2node_2utils_8h_source.html":[9,0,200],
 "build_2doc_2spa_2pod_2filter_8h.html":[9,0,51],
 "build_2doc_2spa_2pod_2filter_8h_source.html":[9,0,51],
 "build_2doc_2spa_2support_2i18n_8h.html":[9,0,64],
 "build_2doc_2spa_2support_2i18n_8h.html#af3aa0f8921abf9d572c9fde4a9d0825d":[9,0,64,2],
 "build_2doc_2spa_2support_2i18n_8h_source.html":[9,0,64],
-"build_2doc_2spa_2support_2log_8h.html":[9,0,99],
-"build_2doc_2spa_2support_2log_8h.html#a750a6ac2af9bf84c4b59af14d6cbe22f":[9,0,99,16],
-"build_2doc_2spa_2support_2log_8h.html#ab60b078a5687f091f11d951899e7c270":[9,0,99,15],
-"build_2doc_2spa_2support_2log_8h_source.html":[9,0,99],
-"build_2doc_2spa_2support_2loop_8h.html":[9,0,103],
-"build_2doc_2spa_2support_2loop_8h.html#a2b1b3decfe2f7f50d690dba084a6f83e":[9,0,103,34],
-"build_2doc_2spa_2support_2loop_8h.html#a3b9f5ee85f8290ef943a23ceaf5181eb":[9,0,103,37],
-"build_2doc_2spa_2support_2loop_8h.html#a84200b300d2836d9cf38eb5a66e91746":[9,0,103,35],
-"build_2doc_2spa_2support_2loop_8h.html#acc69b9f0b161fd5ea86a3cc79a2bfa88":[9,0,103,33],
-"build_2doc_2spa_2support_2loop_8h_source.html":[9,0,103],
-"build_2doc_2spa_2support_2thread_8h.html":[9,0,183],
-"build_2doc_2spa_2support_2thread_8h.html#a7454dd6c4ac2967b5c53936dc6ec00b5":[9,0,183,3],
-"build_2doc_2spa_2support_2thread_8h_source.html":[9,0,183],
-"build_2doc_2spa_2utils_2keys_8h.html":[9,0,90],
-"build_2doc_2spa_2utils_2keys_8h_source.html":[9,0,90],
-"build_2doc_2spa_2utils_2type_8h.html":[9,0,194],
-"build_2doc_2spa_2utils_2type_8h_source.html":[9,0,194],
+"build_2doc_2spa_2support_2log_8h.html":[9,0,100],
+"build_2doc_2spa_2support_2log_8h.html#a750a6ac2af9bf84c4b59af14d6cbe22f":[9,0,100,16],
+"build_2doc_2spa_2support_2log_8h.html#ab60b078a5687f091f11d951899e7c270":[9,0,100,15],
+"build_2doc_2spa_2support_2log_8h_source.html":[9,0,100],
+"build_2doc_2spa_2support_2loop_8h.html":[9,0,104],
+"build_2doc_2spa_2support_2loop_8h.html#a2b1b3decfe2f7f50d690dba084a6f83e":[9,0,104,34],
+"build_2doc_2spa_2support_2loop_8h.html#a3b9f5ee85f8290ef943a23ceaf5181eb":[9,0,104,37],
+"build_2doc_2spa_2support_2loop_8h.html#a84200b300d2836d9cf38eb5a66e91746":[9,0,104,35],
+"build_2doc_2spa_2support_2loop_8h.html#acc69b9f0b161fd5ea86a3cc79a2bfa88":[9,0,104,33],
+"build_2doc_2spa_2support_2loop_8h_source.html":[9,0,104],
+"build_2doc_2spa_2support_2thread_8h.html":[9,0,184],
+"build_2doc_2spa_2support_2thread_8h.html#a7454dd6c4ac2967b5c53936dc6ec00b5":[9,0,184,3],
+"build_2doc_2spa_2support_2thread_8h_source.html":[9,0,184],
+"build_2doc_2spa_2utils_2keys_8h.html":[9,0,91],
+"build_2doc_2spa_2utils_2keys_8h_source.html":[9,0,91],
+"build_2doc_2spa_2utils_2type_8h.html":[9,0,195],
+"build_2doc_2spa_2utils_2type_8h_source.html":[9,0,195],
 "builder_8h.html":[9,0,16],
 "builder_8h.html#a3b0caae7fd8281ebc926bbac640c4f5f":[9,0,16,4],
 "builder_8h.html#adc6048dc20a1aa0eb2b4f578b8e63288":[9,0,16,5],
@@ -217,8 +223,8 @@ var NAVTREEINDEX0 =
 "context_8h.html":[9,0,26],
 "context_8h.html#a1cb169be36ad0e32410951c8ff535743":[9,0,26,0],
 "context_8h_source.html":[9,0,26],
-"control_2type-info_8h.html":[9,0,185],
-"control_2type-info_8h_source.html":[9,0,185],
+"control_2type-info_8h.html":[9,0,186],
+"control_2type-info_8h_source.html":[9,0,186],
 "control_8c.html":[9,0,27],
 "control_8c.html#a22b3038a83c84150025613ffadc4568e":[9,0,27,6],
 "control_8c.html#a2676d48aaa968bb77e06846004e0b9d0":[9,0,27,4],
@@ -243,11 +249,5 @@ var NAVTREEINDEX0 =
 "data-loop_8h.html":[9,0,34],
 "data-loop_8h.html#aa9cf928c292b70257b5533ca6702fecf":[9,0,34,0],
 "data-loop_8h_source.html":[9,0,34],
-"dbus_8h.html":[9,0,35],
-"dbus_8h.html#a3b4641d430f6892c79f6a02284349dbf":[9,0,35,11],
-"dbus_8h.html#a9c9264eb38a39811f9a1103bef5d1d99":[9,0,35,12],
-"dbus_8h.html#ab06fb2f95424f573700caeabf9424784":[9,0,35,10],
-"dbus_8h_source.html":[9,0,35],
-"debug_2buffer_8h.html":[9,0,13],
-"debug_2buffer_8h_source.html":[9,0,13]
+"dbus_8h.html":[9,0,35]
 };
