@@ -6,6 +6,7 @@ var structstream =
     [ "buffers", "structstream.html#a5dad5c71aca03c94d3bf873b9f575c58", null ],
     [ "callbacks", "structstream.html#a2a4b596a8fd6684e563544921631bfde", null ],
     [ "change_mask_all", "structstream.html#a2afd916c12d7d91bddd23b30f709c582", null ],
+    [ "clock", "structstream.html#ad363aa68c22a0152c3cc4f08f750dec9", null ],
     [ "clock_id", "structstream.html#a5e13d0a14c7715023a92ea6e5d1b603e", null ],
     [ "context", "structstream.html#a9de6d02605037e6dfe335552c2e398a3", null ],
     [ "context_listener", "structstream.html#a669c175165bd2b3898f2a02d37ac2819", null ],
@@ -16,6 +17,7 @@ var structstream =
     [ "disconnecting", "structstream.html#a5e861c5f495c43750eda66e177a1b9c3", null ],
     [ "drained", "structstream.html#a0b67dcf51974d8cf6b73151658d42be3", null ],
     [ "draining", "structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19", null ],
+    [ "driving", "structstream.html#ae6fe3ec73dcd1f9fe47cec98c7244a17", null ],
     [ "endpoint", "structstream.html#acd5a7c8dc94d1197352ab7e870ac8363", null ],
     [ "flags", "structstream.html#a41be007c6de999aff0def3e6bb0e1652", null ],
     [ "format", "structstream.html#aeb482c196ab95fae6b29d39932cd05ef", null ],
@@ -56,5 +58,6 @@ var structstream =
     [ "seq", "structstream.html#a205abb8810d099ecd79ff9afd7931428", null ],
     [ "this", "structstream.html#a00d21063b64b6339d257433d02a0d5bc", null ],
     [ "time", "structstream.html#abc4bd0629266976bb016a722584ed09c", null ],
+    [ "using_drive", "structstream.html#a9eacd2695c1f83ee404c5668b60f5611", null ],
     [ "warn_mlock", "structstream.html#a1000143671503ec1a7a1a0ddad5a0b5b", null ]
 ];
\ No newline at end of file
